summaryrefslogtreecommitdiff
path: root/NxWidgets/libnxwidgets/include/cglyphbutton.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'NxWidgets/libnxwidgets/include/cglyphbutton.hxx')
-rw-r--r--NxWidgets/libnxwidgets/include/cglyphbutton.hxx17
1 files changed, 13 insertions, 4 deletions
diff --git a/NxWidgets/libnxwidgets/include/cglyphbutton.hxx b/NxWidgets/libnxwidgets/include/cglyphbutton.hxx
index aad348ca9..b4b1a5657 100644
--- a/NxWidgets/libnxwidgets/include/cglyphbutton.hxx
+++ b/NxWidgets/libnxwidgets/include/cglyphbutton.hxx
@@ -73,7 +73,7 @@
/****************************************************************************
* Included Files
****************************************************************************/
-
+
#include <nuttx/config.h>
#include <stdint.h>
@@ -87,11 +87,11 @@
/****************************************************************************
* Pre-Processor Definitions
****************************************************************************/
-
+
/****************************************************************************
* Implementation Classes
****************************************************************************/
-
+
#if defined(__cplusplus)
namespace NXWidgets
@@ -156,7 +156,16 @@ namespace NXWidgets
virtual void onClick(nxgl_coord_t x, nxgl_coord_t y);
/**
- * Raises an action event and redraws the button.
+ * Raises an action event.
+ *
+ * @param x The x coordinate of the mouse.
+ * @param y The y coordinate of the mouse.
+ */
+
+ virtual void onPreRelease(nxgl_coord_t x, nxgl_coord_t y);
+
+ /**
+ * Raises a release event and redraws the button.
*
* @param x The x coordinate of the mouse.
* @param y The y coordinate of the mouse.